Crate wasm_bindgen_derive_macro

Crate wasm_bindgen_derive_macro 

A proc-macro to be re-exported by wasm-bindgen-derive. We need this trampoline to enforce the correct bounds on the wasm-bindgen and js-sys dependencies, but those are technically not the dependencies of this crate, but only of the code it generates.

Derive Macros

TryFromJsValue
Derives a TryFrom<&JsValue> for a type exported using #[wasm_bindgen].